@@ -26,14 +26,10 @@ from multiprocessing import freeze_support
 try:
     from .Ui.CutPdfPicUi import Ui_CutPdfPic
     from .Function.optionDb import getOption, InsertDb
-    # from .Function.cut_pdF_pic import get_pdf_color_page
 
 except:
-    # pass
-
     from Ui.CutPdfPicUi import Ui_CutPdfPic
     from Function.optionDb import getOption, InsertDb
-    from Function.cut_pdF_pic import get_pdf_color_page
 
 import sys
 import time
