@@ -21,6 +21,7 @@ import json
 import sqlite3
 import random
 import traceback
+
 '''
 
 OCR的结果保存到Excel表中的方法
@@ -74,10 +75,17 @@ class OcrTable(QWidget, Ui_OcrTable):
     #初始化UI界面
     def UiInit(self):
         ui_list = getOption("SqlExcel")
+        print(ui_list)
         # 判断类型
         if isinstance(ui_list, list):
             if len(ui_list) == 1:
                 self.tablePathEdit.setText(ui_list[0][1])
+                # if isinstance(ui_list[0][2], int):
+                try:
+                    int(ui_list[0][2])
+                    self.FileDeepEdit.setText(ui_list[0][2])
+                except:
+                    print("不用设置默认的层级")
         elif isinstance(ui_list, str):
             pass
         else:
@@ -157,6 +165,9 @@ class OcrTable(QWidget, Ui_OcrTable):
 
     def startwork(self):
         self.checkToken(6, "Sql内容保存到Excel")
+        checkTuple = ("SqlExcel", self.tablePathEdit.text(), self.FileDeepEdit.text(), "", '')
+        g = InsertDb(checkTuple)
+
         if self.run_code:
             # self.true_run()
     # def true_run(self):
