@@ -4,9 +4,11 @@
 try:
     from Ui.SplitPdfUi import Ui_SplitPdf
     from Function.splite_pdf import split_pdfs_in_tb
+    from Function.optionDb import getOption, InsertDb
 except:
     from .Ui.SplitPdfUi import Ui_SplitPdf
     from .Function.splite_pdf import split_pdfs_in_tb
+    from .Function.optionDb import getOption, InsertDb
 import sys
 from PyQt5.QtGui import *
 from PyQt5.QtCore import *
@@ -65,7 +67,7 @@ class SplitPdf(QWidget, Ui_SplitPdf):
         self.TablePath = ''
         self.PdfPathtip.setVisible(False)
         self.WidgetColorSignal.connect(self.WidgetColorFun)
-
+        self.UiInit()
     def WidgetColorFun(self, statu):
         if statu == "success":
             self.widget_5.setStyleSheet("border-width: 2px;border-style: solid;border-color: rgb(32,205,32);")
@@ -74,6 +76,26 @@ class SplitPdf(QWidget, Ui_SplitPdf):
         else:
             self.widget_5.setStyleSheet("border-width: 2px;border-style: solid;border-color: rgb(0,0,0);")
 
+    #初始化UI界面
+    def UiInit(self):
+        ui_list = getOption("splitPdf")
+        print(ui_list)
+        # 判断类型
+        if isinstance(ui_list, list):
+            if len(ui_list) == 1:
+                self.pdfPathEdit.setText(ui_list[0][1])
+                # if isinstance(ui_list[0][2], int):
+                # try:
+                #     int(ui_list[0][2])
+                #     self.FileDeepEdit.setText(ui_list[0][2])
+                # except:
+                #     print("不用设置默认的层级")
+        elif isinstance(ui_list, str):
+            pass
+        else:
+            self.textEdit.setText(str(ui_list))
+
+
     def closeMain(self):
         if self.communication:
             try:
@@ -100,7 +122,10 @@ class SplitPdf(QWidget, Ui_SplitPdf):
 
     # 开始获取隔页
     def splitPdf(self):
+        checkTuple = ("splitPdf", self.pdfPathEdit.text(), "", "", '')
+        g = InsertDb(checkTuple)
         try:
+
             self.PdfPathtip.setVisible(False)
             self.plainTextEdit.clear()
             self.btn2.setText("正在执行")
